@@ -26,7 +26,7 @@
 
 class BamfView;
 
-class BamfFactory: public QObject
+class __attribute__ ((visibility ("default"))) BamfFactory: public QObject
 {
     Q_OBJECT
 
