@@ -29,7 +29,7 @@
 
 class OrgAyatanaBamfWindowInterface;
 
-class BamfWindow: public BamfView
+class __attribute__ ((visibility ("default"))) BamfWindow: public BamfView
 {
     Q_OBJECT
 
